# Copyright © 2013, 2021 Nick Bowler
# License GPLv3+: GNU General Public License version 3 or any later version.
# This is free software: you are free to change and redistribute it.
# There is NO WARRANTY, to the extent permitted by law.

EAPI=7

SHA1=98d6f309f4d880c2c319c2cadebf756574892545

MY_PN=OpenGL-Refpages

DESCRIPTION="Man pages for OpenGL"
HOMEPAGE="http://www.opengl.org/sdk/docs/man/"
SRC_URI="https://github.com/KhronosGroup/$MY_PN/archive/$SHA1.tar.gz -> $P.tar.gz"

LICENSE="SGI-B-2.0 OPL"
SLOT="0"
KEYWORDS="~amd64"
IUSE=""

BDEPEND="dev-libs/libxslt
	app-text/docbook-xsl-stylesheets
	app-text/docbook-mathml-dtd
	sys-apps/sed"

S=$WORKDIR/$MY_PN-$SHA1

src_compile () {
	cat >GNUmakefile <<'EOF'
SOURCES := $(wildcard gl2.1/*.xml)
MANXSL   = $(BROOT)/usr/share/sgml/docbook/xsl-stylesheets/manpages/docbook.xsl
BROOT    =

all: $(SOURCES:.xml=.man)
.PHONY: all

%.man: %.xml
	sed -e '/<refentry[ >]/r versinfo' -e '/<refmeta>/r $(@D)/metainfo' $< >$@.tmp
	:; { cd $(@D) && xsltproc --nonet --noout '$(MANXSL)' -; } <$@.tmp
	rm -f $@.tmp
.PHONY: %.man
EOF

	for dir in gl2.1; do
		case $dir in
		gl2.1) heading='OpenGL 2.1 Reference Manual' ;;
		*) heading='OpenGL Reference Manual' ;;
		esac

		cat >"$dir/metainfo" <<-EOF
			<refmiscinfo class="manual">$heading</refmiscinfo>
			<refmiscinfo class="source">Khronos Group</refmiscinfo>
		EOF
	done

	cat >versinfo <<-EOF
		<refentryinfo>
			<date>${PV:0:4}-${PV:4:2}-${PV:6:2}</date>
		</refentryinfo>
	EOF

	emake -f GNUmakefile BROOT="${BROOT%/}"
}

src_install() {
	doman gl2.1/*.3G
}
